<?php
/*
 * CSE 154 Autumn 18
 * Lecture 18 example:
 * pointsofinterest.php web service to demonstrate basic GET parameters with associative arrays.
 * by getting points of interests from a city.
 *
 * Web service details:
 *   Required GET parameters:
 *     - city
 *   examples
 *     - city=all
 *     - city=Seattle
 *   Output Format:
 *   - txt
 *   Output Details:
 *     - If city parameter is passed and is set to all, it will output a JSON encoded object
 *       that contains all of the cities and points of interest for those cities
 *     - If city parameter is passed with a city that is in our associative array, it will
 *       display a message that contains the city and the point of interest.
 *     - If city parameter is passed with a city that is not inour associative array, it will
 *       display an error message.
 *   - Else outputs error message.
 */

  /* First check if the city is set */
  if (isset($_GET["city"])) {
    /* may want to make the city lower case */
    $city = $_GET["city"];

    $attractions = get_list();
    // $attractions = get_list_from_file();

    if (strcmp($city, "all") == 0) {
      header("Content-type: application/json");
      print_r(json_encode($attractions));
    }
    else {
      header("Content-type: text/plain");
      if (array_key_exists($city, $attractions)) {
        /* double check if the city is in the list of attractions */
        echo "The best place to visit in " . $city .  " is " . $attractions[$city] . ".\n";
      }
      else {
        echo "I did not find that city in my list. Perhaps we can add it some day. ";
      }
    }
  }
  else {
    /* Otherwise we have an error, and should say so. */
    echo "You need to pass in a parameter city for this web service. ";
  }


 /*
   Create an associative array called attractions that stores the name of a city associated with an
    attraction you might want to see in that city.
    For instance, if you want to go to Boston, you might want to go to Boston Harbor.
    Initialize this array with at least 5 city => attraction pairs.
    @return the associative array of city/attraction pairs.
 */
 function get_list() {

   /* This code is used when we want to use attractions that are hard coded in our PHP */
   $attractions = array("Seattle" => "Space Needle",
                         "New York" => "Ellis Island",
                         "Boston" => "Boston Harbor",
                         "Philadelphia" => "Valley Forge",
                         "Detroit" => "The Henry Ford Museum",
                         "Paris" => "Eiffel Tower",
                         "Vancouver BC" => "Stanley Park",
                         "Tokyo" => "Mt. Fuji",
                         "Beijing" => "Great Wall",
                         "London" => "Big Ben");


   /* add an extra city => attraction association in your array */
  $attractions["San Franciso"] = "Fisherman's Warf";

  return $attractions;
 }

 /*
   Read an list of city/attractions in from a file and return an associative array
   of the pairs
   @return the associative array of city/attraction pairs.
 */
 function get_list_from_file() {
   $contents = file("cities.txt", FILE_IGNORE_NEW_LINES);
   $attractions = array();
   foreach ($contents as $line) {
     $parts = explode(",", $line);
     $attractions[$parts[0]] = $parts[1];
   }
   return $attractions;
 }

?>
